==> fet_6.7.6.orig.tar.bz2: fet-6.7.6/src/interface/addconstraintteachersmaxthreeconsecutivedaysform.h <==
/***************************************************************************
                          addconstraintteachersmaxthreeconsecutivedaysform.h  -  description
                             -------------------
    begin                : 2021
    copyright            : (C) 2021 by Lalescu Liviu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTTEACHERSMAXTHREECONSECUTIVEDAYSFORM_H
#define ADDCONSTRAINTTEACHERSMAXTHREECONSECUTIVEDAYSFORM_H

#include "ui_addconstraintteachersmaxthreeconsecutivedaysform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class AddConstraintTeachersMaxThreeConsecutiveDaysForm : public QDialog, Ui::AddConstraintTeachersMaxThreeConsecutiveDaysForm_template  {
	Q_OBJECT
public:
	AddConstraintTeachersMaxThreeConsecutiveDaysForm(QWidget* parent);
	~AddConstraintTeachersMaxThreeConsecutiveDaysForm();

	void updateExceptionCheckBox();

public slots:
	void addCurrentConstraint();
};

#endif

==> fet_6.8.5.orig.tar.bz2: fet-6.8.5/src/interface/addconstraintteachersmaxthreeconsecutivedaysform.h <==
/***************************************************************************
                          addconstraintteachersmaxthreeconsecutivedaysform.h  -  description
                             -------------------
    begin                : 2021
    copyright            : (C) 2021 by Liviu Lalescu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTTEACHERSMAXTHREECONSECUTIVEDAYSFORM_H
#define ADDCONSTRAINTTEACHERSMAXTHREECONSECUTIVEDAYSFORM_H

#include "ui_addconstraintteachersmaxthreeconsecutivedaysform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class AddConstraintTeachersMaxThreeConsecutiveDaysForm : public QDialog, Ui::AddConstraintTeachersMaxThreeConsecutiveDaysForm_template  {
	Q_OBJECT
public:
	AddConstraintTeachersMaxThreeConsecutiveDaysForm(QWidget* parent);
	~AddConstraintTeachersMaxThreeConsecutiveDaysForm();

	void updateExceptionCheckBox();

public slots:
	void addCurrentConstraint();
};

#endif
